@@ -1,9 +1,12 @@
 import numpy as np
 import math
 import itertools
-from . import Formatter as cc_Formatter
+from . import format_args as cc_format_args
 from . import array as cc_array
 from . import maths as cc_maths
+# import ccalafiore.format_args
+# import ccalafiore.array
+# import ccalafiore.maths
 
 
 def n_conditions_to_combinations(
@@ -28,7 +31,6 @@ def n_conditions_to_combinations(
 
     n_variables = len(n_conditions)
     if n_variables > 0:
-        from ccalafiore.array import pad_array_from_n_samples_target
         variables = np.arange(n_variables)
         # n_conditions = np.asarray(n_conditions, dtype=int)
         # conditions = n_conditions_to_conditions(n_conditions)
@@ -81,7 +83,7 @@ def n_conditions_to_combinations(
         indexes_combinations[axis_combinations] = slice(None)
 
         # combinations[tuple(indexes_combinations)] = np.expand_dims(
-        #     pad_array_from_n_samples_target(conditions[-1], n_samples_target=n_combinations),
+        #     cc_array.pad_array_from_n_samples_target(conditions[-1], n_samples_target=n_combinations),
         #     axis=axis_variables)
         cumulative_n_combinations = n_conditions[i_variable]
         for i_variable in variables_in_order[1:]:
@@ -94,7 +96,7 @@ def n_conditions_to_combinations(
 
             indexes_combinations[axis_variables] = i_variable
             if cumulative_combinations.size < n_combinations:
-                combinations[tuple(indexes_combinations)] = pad_array_from_n_samples_target(
+                combinations[tuple(indexes_combinations)] = cc_array.pad_array_from_n_samples_target(
                     cumulative_combinations, n_samples_target=n_combinations)
             elif cumulative_combinations.size == n_combinations:
                 combinations[tuple(indexes_combinations)] = cumulative_combinations
@@ -237,7 +239,6 @@ def conditions_to_combinations(
 
     n_variables = len(conditions)
     if n_variables > 0:
-        from ccalafiore.array import pad_array_from_n_samples_target
         variables = np.arange(n_variables)
         # conditions = np.asarray(conditions, dtype=object)
         n_conditions = conditions_to_n_conditions(conditions)
@@ -298,7 +299,7 @@ def conditions_to_combinations(
         indexes_combinations[axis_combinations] = slice(None)
 
         # combinations[tuple(indexes_combinations)] = np.expand_dims(
-        #     pad_array_from_n_samples_target(conditions[-1], n_samples_target=n_combinations),
+        #     cc_array.pad_array_from_n_samples_target(conditions[-1], n_samples_target=n_combinations),
         #     axis=axis_variables)
         cumulative_n_combinations = n_conditions[i_variable]
         for i_variable in variables_in_order[1:]:
@@ -311,7 +312,7 @@ def conditions_to_combinations(
 
             indexes_combinations[axis_variables] = i_variable
             if cumulative_combinations.size < n_combinations:
-                combinations[tuple(indexes_combinations)] = pad_array_from_n_samples_target(
+                combinations[tuple(indexes_combinations)] = cc_array.pad_array_from_n_samples_target(
                     cumulative_combinations, n_samples_target=n_combinations)
             elif cumulative_combinations.size == n_combinations:
                 combinations[tuple(indexes_combinations)] = cumulative_combinations
@@ -370,8 +371,6 @@ def trials_to_combinations(
 
 def trials_to_conditions(trials, axis_combinations=0, variables=None):
 
-    from ccalafiore.array import advanced_indexing
-
     axis_variables = int(not(bool(axis_combinations)))
     if variables is None:
         n_variables = trials.shape[axis_variables]
@@ -385,18 +384,13 @@ def trials_to_conditions(trials, axis_combinations=0, variables=None):
 
     conditions = np.empty(n_variables, dtype=object)
 
-    indexes_trials_adv = np.empty(2, dtype=object)
-    indexes_trials_adv[axis_combinations] = np.arange(trials.shape[axis_combinations])
-
-    indexes_trials_slice = np.full(2, 0, dtype=object)
-    indexes_trials_slice[axis_combinations] = slice(None)
-    indexes_trials_slice = tuple(indexes_trials_slice)
+    indexes_trials = np.empty(2, dtype=object)
+    indexes_trials[axis_combinations] = slice(0, trials.shape[axis_combinations], 1)
 
     for i_variable in range(n_variables):
 
-        indexes_trials_adv[axis_variables] = variables[i_variable]
-        trials_variables_i = trials[advanced_indexing(indexes_trials_adv)]
-        trials_variables_i = trials_variables_i[indexes_trials_slice]
+        indexes_trials[axis_variables] = variables[i_variable]
+        trials_variables_i = trials[tuple(indexes_trials)]
 
         conditions[i_variable] = np.unique(trials_variables_i)
 
@@ -441,13 +435,13 @@ def conditions_to_phases_of_blocks_of_shuffled_combinations(
         variables_split=variables_split,
         n_repetitions_variables_repeated_per_shuffle=n_repetitions_variables_repeated_per_shuffle)
 
-    dict_arguments = cc_Formatter.format_shape_arguments(dict_arguments, n_phases)
+    dict_arguments = cc_format_args.format_shape_arguments(dict_arguments, n_phases)
     n_repetitions_combinations = dict_arguments['n_repetitions_combinations']
     n_repetitions_variables_repeated_per_block = dict_arguments['n_repetitions_variables_repeated_per_block']
     variables_split = dict_arguments['variables_split']
     n_repetitions_variables_repeated_per_shuffle = dict_arguments['n_repetitions_variables_repeated_per_shuffle']
 
-    # dict_arguments = cc_Formatter.format_shape_arguments(dict_arguments, n_phases)
+    # dict_arguments = cc_format_args.format_shape_arguments(dict_arguments, n_phases)
     # locals().update(dict_arguments)
 
     phases_of_blocks_of_shuffled_combinations = np.empty(n_phases, dtype=object)
@@ -476,7 +470,12 @@ def n_conditions_to_phases_of_blocks_of_shuffled_combinations(
         variables_split=variables_split,
         n_repetitions_variables_repeated_per_shuffle=n_repetitions_variables_repeated_per_shuffle)
 
-    cc_Formatter.format_shape_arguments(dict_arguments, n_phases)
+    dict_arguments = cc_format_args.format_shape_arguments(dict_arguments, n_phases)
+
+    n_repetitions_combinations = dict_arguments['n_repetitions_combinations']
+    n_repetitions_variables_repeated_per_block = dict_arguments['n_repetitions_variables_repeated_per_block']
+    variables_split = dict_arguments['variables_split']
+    n_repetitions_variables_repeated_per_shuffle = dict_arguments['n_repetitions_variables_repeated_per_shuffle']
 
     phases_of_blocks_of_shuffled_combinations = np.empty(n_phases, dtype=object)
 
