@@ -10,19 +10,10 @@ def rint(num):
         int_up = math.ceil(num)
         if int_down == int_up:
             return int_down
-        elif num < (int_down + 0.5):
-            return int_down
-        else:
+        elif num >= (int_down + 0.5):
             return int_up
-    else:
-        return int(num)
-
-
-def convert_to_int(num):
-    if isinstance(num, int):
-        return num
-    elif str(num).__contains__('.'):
-        return rint(num)
+        else:
+            return int_down
     else:
         return int(num)
 
@@ -58,36 +49,15 @@ def convert_to_int_or_float(num):
             raise TypeError('num')
 
 
-def if_its_str_contains_a_dot_convert_to_float_else_int(num):
-
-    if isinstance(num, int):
-        num_converted = num
-    elif str(num).__contains__('.'):
-        if isinstance(num, float):
-            num_converted = num
-        else:
-            num_converted = float(num)
-    else:
-        num_converted = int(num)
-
-    return num_converted
-
-
 def if_equal_to_the_nearest_int_convert_to_int_else_float(num):
     if isinstance(num, int):
-        num_converted = num
+        return num
     else:
-
         num_rounded = rint(num)
         if num_rounded == num:
-            if isinstance(num_rounded, int):
-                num_converted = num_rounded
-            else:
-                num_converted = int(num_rounded)
+            return num_rounded
         else:
-            num_converted = float(num)
-
-    return num_converted
+            return float(num)
 
 
 def factors_of_x(x, y=1):
@@ -113,6 +83,14 @@ def factors_of_x(x, y=1):
     return factors
 
 
+def prod(numbers, start=1):
+
+    product = convert_to_int_or_float(start)
+    for num_i in numbers:
+        product += convert_to_int_or_float(num_i)
+    return product
+
+
 def gamma(z):
     
     print('scipy.special.gamma(z) is more efficient')
