@@ -117,7 +117,8 @@ class Loader:
             self.n_conditions_directories[self.time.level] = len(self.conditions_directories[self.time.level])
 
         self.K = self.n_classes = self.n_conditions_directories[self.level_classes]
-        self.n_samples = math.prod(self.n_conditions_directories)
+        self.n_samples = cc_maths.prod(self.n_conditions_directories)
+        # self.n_samples = math.prod(self.n_conditions_directories)
 
         if batch_size is None:
             if n_batches is None:
