@@ -3,7 +3,7 @@ from ...array import samples_in_arr1_are_in_arr2  # , advanced_indexing
 from ...combinations import (
     trials_to_conditions, conditions_to_n_conditions,
     n_conditions_to_combinations, conditions_to_combinations)
-from ..reshape import merge_axes, merge_axes_and_add_axes_removing_info_to_axis_receiving
+from ..reshape import merge_axes_and_add_axes_removing_info_to_axis_receiving
 
 
 def from_2_arrays(
